@@ -2,13 +2,13 @@ author_info = (("Dmitry Orlov", "me@mosquito.su"),)
 
 package_info = (
     "This module is the simplest way to enable compression support "
-    "for `aiohttp` server applications globally."
+    "for aiohttp server applications globally."
 )
 package_license = "Apache Software License"
 
 team_email = "me@mosquito.su"
 
-version_info = (0, 1, 1)
+version_info = (0, 1, 3)
 
 __author__ = ", ".join("{} <{}>".format(*info) for info in author_info)
 __version__ = ".".join(map(str, version_info))
